==> sgw_front-0.0.1.tgz: package/index.js <==
//модуль для клиента
'use strict';
// это клиент

// Зависимости
let timestamp = require('time-stamp');
let nanoid = require('nanoid');
let axios = require('axios');
const jwt        = require('jsonwebtoken');



function getHeaders(){
    const headers = {
        systemtoken: systemtoken
    };
    if (localStorage.getItem("access_token") !== null){
        headers.access_token = localStorage.getItem("access_token");
    }
    return headers
}

function getBaseUrl(){
    if (localStorage.getItem("baseUrl") !== null){
        return localStorage.getItem("baseUrl")
    } else {
        localStorage.setItem('baseUrl', baseUrl);
        return baseUrl
    }
}

async function checkAndRefreshTokens(){
    // сначала проверяем есть ли сохраненные токены
    log('Проверка токена и обновление при необходимости', 'info');
    const access_token_expireIn = localStorage.getItem("access_token_expireIn");
    const access_token = localStorage.getItem("access_token");
    const refresh_token = localStorage.getItem("refresh_token");

    const now = Math.floor(Date.now() / 1000);
    if (access_token && (access_token_expireIn-now)>10){
        log('access_token ещё свежий. Обновление не требуется', 'info');
        // Т.е. если токен есть и он не просрочен - добавляем в хедер
    } else if (access_token && (access_token_expireIn-now)<10){
        // Если токен есть и он просрочен - обновляем пару токенов, сохраняем и новый access_token добавляем в хедер
        log('Обновление access_token', 'info');
        const reqParams = {
            refresh_token: refresh_token
        };
        try {
            const resp = await axios.put(
                getBaseUrl() + '/sgwc/apigw_fs/login',
                reqParams,
                {headers: {systemtoken: systemtoken}}
            );
            if (resp.data.result === 'ok') {
                log('Произошло обновление токенов', 'info');
                localStorage.setItem('hasManyProfiles', resp.data.data.userData.hasManyProfiles);
                localStorage.setItem('userLogin', resp.data.data.userData.userLogin);
                localStorage.setItem('userEmail', resp.data.data.userData.userEmail);
                localStorage.setItem('urlUserAvatar', resp.data.data.userData.urlUserAvatar);
                localStorage.setItem('userProfile', resp.data.data.userData.userProfile.profileName);
                localStorage.setItem('access_token', resp.data.data.tokensData.access_token);
                localStorage.setItem('access_token_expireIn', resp.data.data.tokensData.expiresIn);
                localStorage.setItem('refresh_token', resp.data.data.tokensData.refresh_token);
            } else {
                log('Рефреш-токен устарел. Осуществляется разлогирование', 'wrn');
                // значит сначала удаляем сторадж
                localStorage.removeItem('userLogin');
                localStorage.removeItem('userEmail');
                localStorage.removeItem('urlUserAvatar');
                localStorage.removeItem('userEmail');
                localStorage.removeItem('userProfile');
                localStorage.removeItem('hasManyProfiles');
                localStorage.removeItem('access_token');
                localStorage.removeItem('access_token_expireIn');
                localStorage.removeItem('refresh_token');
                localStorage.removeItem('baseUrl');
                this.$router.push('/auth/login');
            }
        } catch (e) {
            log('Ошибка обращения к серверу', 'error');
            //this.$message.success(`Ошибка обращения к серверу (при получении токена)`);
        }
    } else {
        log('Токены отсутствуют (невозможная ситуация)', 'error');
    }
}

async function callGet (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.get(
            getBaseUrl() + reqPath,
            {
                params:reqParams,
                headers: getHeaders()
            });
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callPost (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.post(
            getBaseUrl() + reqPath,
            reqParams,
            {headers: getHeaders()}
        );
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callPut (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.put(
            getBaseUrl() + reqPath,
            reqParams,
            {headers: await getHeaders()}
        );
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callDel (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.delete(
            getBaseUrl() + reqPath,
            {
                params:reqParams,
                headers: getHeaders()
            });
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

function log (logString, mark){
    let currentLogType = localStorage.getItem("logType") || logType
    if ((currentLogType === 'dev') || ((currentLogType === 'uat' && (mark === 'error') ||(mark === 'wrn')))) {
        const msMark = mark || 'ok' ;
        console.log(`${timestamp('[DD-MM-YYYY HH:mm:ss.ms]')}: (${msMark}) ${logString}` )
    }
    if (((currentLogType === 'dev') || (currentLogType === 'uat')) && (!mark)) {
        console.log(logString)
    }
}

function login (loginParams){
    // loginParams.userEmail
    // loginParams.userPass
    // loginParams.
    const reqParams = {
        userEmail: loginParams.userEmail,
        userPass: loginParams.userPass,
    };
}

function logout (loginParams){

}
function changeProfile (){

}

function checkAndUpdateLogin (){

}

function start (startParams){
    // startParams.systemtoken
    // startParams.logType // Тип логирования (prod, uat, dev)
    // startParams.
    //localStorage.setItem('logType', startParams.logType);
    console.log('Лог вызванный из подключаемого модуля')
}


module.exports = {
// Работа с запросами
    // Авторизация
    login: login, // С профилем по умолчанию или последним использованным профилем
    // Смена профиля
    changeProfile: changeProfile, // Изменение используемого профиля
    // Разлогирование
    logout: logout,
    // Проверка действия авторизации (по вреимени, возможно профиль)
    checkAndUpdateLogin: checkAndUpdateLogin,
    // Для вызова апи
    callGet: callGet,
    callPost: callPost,
    callPut: callPut,
    callDel: callDel,
    start: start,
};

==> sgw_front-0.0.2.tgz: package/index.js <==
//модуль для клиента
'use strict';
// это клиент

// Зависимости
let timestamp = require('time-stamp');
let nanoid = require('nanoid');
let axios = require('axios');
const jwt        = require('jsonwebtoken');



function getHeaders(){
    const headers = {
        systemtoken: systemtoken
    };
    if (localStorage.getItem("access_token") !== null){
        headers.access_token = localStorage.getItem("access_token");
    }
    return headers
}

function getBaseUrl(){
    if (localStorage.getItem("baseUrl") !== null){
        return localStorage.getItem("baseUrl")
    } else {
        localStorage.setItem('baseUrl', baseUrl);
        return baseUrl
    }
}

async function checkAndRefreshTokens(){
    // сначала проверяем есть ли сохраненные токены
    log('Проверка токена и обновление при необходимости', 'info');
    const access_token_expireIn = localStorage.getItem("access_token_expireIn");
    const access_token = localStorage.getItem("access_token");
    const refresh_token = localStorage.getItem("refresh_token");

    const now = Math.floor(Date.now() / 1000);
    if (access_token && (access_token_expireIn-now)>10){
        log('access_token ещё свежий. Обновление не требуется', 'info');
        // Т.е. если токен есть и он не просрочен - добавляем в хедер
    } else if (access_token && (access_token_expireIn-now)<10){
        // Если токен есть и он просрочен - обновляем пару токенов, сохраняем и новый access_token добавляем в хедер
        log('Обновление access_token', 'info');
        const reqParams = {
            refresh_token: refresh_token
        };
        try {
            const resp = await axios.put(
                getBaseUrl() + '/sgwc/apigw_fs/login',
                reqParams,
                {headers: {systemtoken: systemtoken}}
            );
            if (resp.data.result === 'ok') {
                log('Произошло обновление токенов', 'info');
                localStorage.setItem('hasManyProfiles', resp.data.data.userData.hasManyProfiles);
                localStorage.setItem('userLogin', resp.data.data.userData.userLogin);
                localStorage.setItem('userEmail', resp.data.data.userData.userEmail);
                localStorage.setItem('urlUserAvatar', resp.data.data.userData.urlUserAvatar);
                localStorage.setItem('userProfile', resp.data.data.userData.userProfile.profileName);
                localStorage.setItem('access_token', resp.data.data.tokensData.access_token);
                localStorage.setItem('access_token_expireIn', resp.data.data.tokensData.expiresIn);
                localStorage.setItem('refresh_token', resp.data.data.tokensData.refresh_token);
            } else {
                log('Рефреш-токен устарел. Осуществляется разлогирование', 'wrn');
                // значит сначала удаляем сторадж
                localStorage.removeItem('userLogin');
                localStorage.removeItem('userEmail');
                localStorage.removeItem('urlUserAvatar');
                localStorage.removeItem('userEmail');
                localStorage.removeItem('userProfile');
                localStorage.removeItem('hasManyProfiles');
                localStorage.removeItem('access_token');
                localStorage.removeItem('access_token_expireIn');
                localStorage.removeItem('refresh_token');
                localStorage.removeItem('baseUrl');
                this.$router.push('/auth/login');
            }
        } catch (e) {
            log('Ошибка обращения к серверу', 'error');
            //this.$message.success(`Ошибка обращения к серверу (при получении токена)`);
        }
    } else {
        log('Токены отсутствуют (невозможная ситуация)', 'error');
    }
}

async function callGet (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.get(
            getBaseUrl() + reqPath,
            {
                params:reqParams,
                headers: getHeaders()
            });
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callPost (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.post(
            getBaseUrl() + reqPath,
            reqParams,
            {headers: getHeaders()}
        );
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callPut (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.put(
            getBaseUrl() + reqPath,
            reqParams,
            {headers: await getHeaders()}
        );
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

async function callDel (reqPath, reqParams) {
    if (localStorage.getItem('access_token')){
        await checkAndRefreshTokens();
    }
    try {
        const resp = await axios.delete(
            getBaseUrl() + reqPath,
            {
                params:reqParams,
                headers: getHeaders()
            });
        return {data: resp.data}
    } catch (e) {
        log('Ошибка обращения к серверу', 'error');
        return {data: {result: 'error', reason: 'Ошибка обращения к серверу'}}
    }
}

function log (logString, mark){
    let currentLogType = localStorage.getItem("logType") || logType
    if ((currentLogType === 'dev') || ((currentLogType === 'uat' && (mark === 'error') ||(mark === 'wrn')))) {
        const msMark = mark || 'ok' ;
        console.log(`${timestamp('[DD-MM-YYYY HH:mm:ss.ms]')}: (${msMark}) ${logString}` )
    }
    if (((currentLogType === 'dev') || (currentLogType === 'uat')) && (!mark)) {
        console.log(logString)
    }
}

async function login (loginParams){
    const reqParams = {
        userEmail: loginParams.userEmail, // Логин
        userPass: loginParams.userPass, // Пароль
    };
    const resp = await this.callGet('/sgwc/apigw_fs/login', reqParams);
    // this.loading = false;
    if (resp.data.result === 'ok'){
        console.log ( resp.data.data)
        // this.log('Успешно выполнен вход пользователя', 'info')

        // localStorage.setItem('hasManyProfiles', resp.data.data.userData.hasManyProfiles);
        // localStorage.setItem('userLogin', resp.data.data.userData.userLogin);
        // localStorage.setItem('userEmail', resp.data.data.userData.userEmail);
        // localStorage.setItem('urlUserAvatar', resp.data.data.userData.urlUserAvatar);
        // localStorage.setItem('userProfile', resp.data.data.userData.userProfile.profileName);
        // localStorage.setItem('access_token', resp.data.data.tokensData.access_token);
        // localStorage.setItem('access_token_expireIn', resp.data.data.tokensData.expiresIn);
        // localStorage.setItem('refresh_token', resp.data.data.tokensData.refresh_token);

        //this.$router.push({name:'Home'});
    }
    else {
        // Если не добавлен (что-то пошло не так)
        console.log ('Ошибка выполнения входа пользователя')
        // this.log('Ошибка выполнения входа пользователя', 'wrn')
        // this.$message.error(resp.data.reason);
    }


}

function logout (loginParams){

}
function changeProfile (){

}

function checkAndUpdateLogin (){

}

function start (startParams){
    // startParams.systemToken
    // startParams.logType // Тип логирования (prod, uat, dev)
    // startParams.
    //localStorage.setItem('logType', startParams.logType);
    console.log('Лог вызванный из подключаемого модуля')
}


module.exports = {
// Работа с запросами
    // Авторизация
    login: login, // С профилем по умолчанию или последним использованным профилем
    // Смена профиля
    changeProfile: changeProfile, // Изменение используемого профиля
    // Разлогирование
    logout: logout,
    // Проверка действия авторизации (по вреимени, возможно профиль)
    checkAndUpdateLogin: checkAndUpdateLogin,
    // Для вызова апи
    callGet: callGet,
    callPost: callPost,
    callPut: callPut,
    callDel: callDel,
    start: start,
};
